
;; (require 'erc)
;; (setq erc-modules '())
;; (erc-update-modules)

(setq erc-modules '(autojoin button completion irccontrols list
			     match menu move-to-prompt
			     netsplit networks noncommands
			     readonly ring scrolltobottom
			     stamp track
			     autoaway truncate))

(setq       
 word-wrap t
 erc-timestamp-only-if-changed-flag nil
 erc-timestamp-format "%D %T "
 erc-hide-timestamps t
 erc-pcomplete-order-nickname-completions t
 erc-insert-timestamp-function 'erc-insert-timestamp-left)

(fset 'yes-or-no-p 'y-or-n-p)
(set-frame-parameter nil 'fullscreen 'fullboth)

(defun erc-put-colors-on-line ()
  "Colorise a message. First, we colorize the sender, then we go through
the message looking for nicks to colorize. "
  ;; makes word boundaries work
  (with-syntax-table erc-button-syntax-table
    (save-excursion
      (goto-char (point-min))
      ;; colorise the nick of the person talking, unless this is an outgoing message, in which case
      ;; something else already does the coloring and we don't want to interfere
      ;; erc-send-this is only t in send-modify-hook, see the lambdas below
      (unless erc-is-sending
	(if (looking-at "<\\([^>]*\\)>")
	    (let ((nick (match-string 1)))
	      (put-text-property (match-beginning 1) (match-end 1) 'face
				 (cons 'foreground-color
				       (erc-get-color-for-nick nick))))))
      ;; go through the message, find nicks and colorise them.
      ;; From erc-button with modifications
      ;; ignore the author, already taken care of by the code above
      (if (looking-at "<\\([^>]*\\)>")(forward-word))
      (while (forward-word 1)
	(setq bounds (bounds-of-thing-at-point 'word))
	(when bounds
	  (setq word (buffer-substring-no-properties
		      (car bounds) (cdr bounds)))
	  (when (or (and (erc-server-buffer-p) (erc-get-server-user word))
		    (and erc-channel-users (erc-get-channel-user word)))
	    (let ((nick ( erc-server-user-nickname  (if (erc-server-buffer-p)
							(erc-get-server-user word)
						      (car (erc-get-channel-user word))))))
	      (put-text-property (car bounds) (cdr bounds) 'face
				 (list
				  (cons 'foreground-color
					(erc-get-color-for-nick nick))
				  :weight 'bold)))))))))

;;put the hooks at the end
(require 'erc)
(add-hook 'erc-insert-modify-hook '(lambda () (let ((erc-is-sending nil)) (erc-put-colors-on-line))) 'attheend)
(add-hook 'erc-send-modify-hook '(lambda () (let ((erc-is-sending t)) (erc-put-colors-on-line))) 'attheend)


(defun erc-get-color-for-nick (nick)
  "Gets a color for NICK. If NICK is specified in erc-nick-color-alist, use it, else hash the nick and get a color from that"
  "yellow")

;; (erc :server "localhost" :nick "Test")
